<?php
/**
 * A init city state class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class CityInitState extends BaseCityState implements Stateable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructo
		parent::__construct(__CLASS__);

		// Set state name
		$this->setStateName('init');
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$stateInstance	An instance of a Stateable class
	 */
	public static final function createCityInitState () {
		// Get new instance
		$stateInstance = new CityInitState();

		// Return the prepared instance
		return $stateInstance;
	}

	/**
	 * Executes the state with given Executor instance
	 *
	 * @param	$executorInstance	An instance of a Executor class
	 * @return	void
	 */
	public function executeState (Executor $executorInstance) {
		// Initialize the daemon
		$executorInstance->initializeDaemon($this);
	}

	/**
	 * Change the state to 'active' when the city daemon has initialized all
	 * tasks, queues, etc.
	 *
	 * @return	void
	 */
	public function citySimulationIsActivated () {
		// Create the new state instance
		CityStateFactory::createCityStateInstanceByName('active');
	}
}

// [EOF]
?>
