<?php
/**
 * An interface for region-information (database) wrapper
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2015 City Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface RegionInformationWrapper extends DatabaseWrapper {
	/**
	 * Removes non-data from given array.
	 *
	 * @param	$data	An array with possible non-data that needs to be removed.
	 * @return	$data	A cleaned up array with only data.
	 */
	function removeNonPublicDataFromArray(array $data);

	/**
	 * Checks whether the user has already founded a region
	 *
	 * @return	$hasFounded		Whether the user has already founded a region
	 */
	function ifUserHasCreatedRegion ();

	/**
	 * Checks whether the given region name is taken
	 *
	 * @param	$regionName		Name of region
	 * @return	$isTaken		Whether the given region name is taken
	 */
	function ifRegionExists ($regionName);

	/**
	 * Creates a region by given name
	 *
	 * @param	$regionName		Name of region
	 * @return	void
	 */
	function createRegionByName ($regionName);
}

// [EOF]
?>
